==> lxqt-globalkeys_0.10.0.orig.tar.gz: lxqt-globalkeys-0.10.0/config/translations/lxqt-config-globalkeyshortcuts_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation type="unfinished">Kuvaus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation type="unfinished">Poista</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="123"/>
        <source>First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="128"/>
        <source>Last</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="133"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="138"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="176"/>
        <source>Close</source>
        <translation type="unfinished">Sulje</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>Description</source>
        <translation type="vanished">Kuvaus</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="vanished">Poista</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Sulje</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Poista</translation>
    </message>
</context>
</TS>

==> lxqt-globalkeys_0.14.0.orig.tar.gz: lxqt-globalkeys-0.14.0/config/translations/lxqt-config-globalkeyshortcuts_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>DBus kutsu</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation type="unfinished">Kuvaus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Tyyppi:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Pikanäppäinmanageri</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Lisää ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation type="unfinished">Poista</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Muokkaa ...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Ensimmäinen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Viimeinen</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="176"/>
        <source>Close</source>
        <translation type="unfinished">Sulje</translation>
    </message>
</context>
</TS>
